@@ -9,6 +9,8 @@ from .helpers import CurrenciesIDs, MarketsIDs
 
 from logging import Logger
 
+from nice_tools.thread_tools import run_in_thread_decorator
+from time import sleep
 
 __all__ = [
     'Bitpin',
@@ -18,7 +20,8 @@ __all__ = [
 class Bitpin:
     def __init__(self, api_key: t.Optional[str] = None, api_secret: t.Optional[str] = None,
                  requests_params: t.Optional[t.Dict] = None,
-                 logger: t.Optional[t.Union[Logger, t.Type[Logger]]] = Logger('Bitpin')):
+                 logger: t.Optional[t.Union[Logger, t.Type[Logger]]] = Logger('Bitpin'),
+                 auto_refresh_token: t.Optional[bool] = False):
         """
         Initialize the Bitpin SDK .
 
@@ -47,6 +50,8 @@ class Bitpin:
 
         self._logger = logger
 
+        self.auto_refresh_token = auto_refresh_token
+
         # set timeout from requests_params
         if requests_params is not None:
             self.__timeout = requests_params.get('timeout') or 10
@@ -57,6 +62,9 @@ class Bitpin:
 
         self.__handle_access_token()
 
+        if self.auto_refresh_token:
+            self._token_cycle()
+
         return
 
     def __handle_access_token(self) -> t.Tuple[str, str]:
@@ -71,6 +79,13 @@ class Bitpin:
 
         return self.__access_token, self.__refresh_token
 
+    @run_in_thread_decorator
+    def _token_cycle(self):
+        sleep(60 * 5)
+        self.__handle_access_token()
+        self._logger.warning('tokens refreshed.')
+        self._token_cycle()
+
     @staticmethod
     def __get_func_args(all_locals: t.Dict, remove_keys=None) -> t.Dict:
         """
